@@ -18,7 +18,8 @@
 //!     .expect("obtained cargo-guppy's PackageGraph");
 //!
 //! // The second argument to HakariBuilder::new specifies a Hakari (workspace-hack) package.
-//! let hakari_package = package_graph.workspace().member_by_name("workspace-hack").unwrap().id();
+//! // In this repository, the package is called "guppy-workspace-hack".
+//! let hakari_package = package_graph.workspace().member_by_name("guppy-workspace-hack").unwrap().id();
 //! let hakari_builder = HakariBuilder::new(&package_graph, Some(hakari_package))
 //!     .expect("HakariBuilder was constructed");
 //!
@@ -124,12 +125,15 @@
 mod cargo_toml;
 #[cfg(feature = "cli-support")]
 pub mod cli_ops;
+pub mod explain;
 mod hakari;
 mod helpers;
 #[cfg(feature = "proptest1")]
 mod proptest_helpers;
 #[cfg(feature = "cli-support")]
 pub mod summaries;
+#[cfg(feature = "cli-support")]
+mod tabular;
 mod toml_out;
 pub mod verify;
 
